Home Loans: Compare home loans from UAE Banks
Description: Find the best home loan for you by comparing home loan offers from all the UAE banks

#### Home Loans
Looking for a home loan? Whether you’re a first time buyer, resident or non-resident, residential or commercial buyer, with compareit4me, you can save substantial time and money by finding the best deal for your needs.

Looking for a home loan? Whether you’re a first time buyer, resident or non-resident, residential or commercial buyer, with compareit4me, you can save substantial time and money by finding the best deal for your needs.
Buying a property is probably the biggest transaction you’re ever likely to make so it pays to shop around for the best loan options. We work closely with UAE’s leading banks to make sure you have an quick and easy way to find and compare home loans. Compare home loans based on; interest rates, loan amounts, down payment requirements, tenures, arrangement fees, early settlement charges and all other applicable loan terms.

- ### Products of the Month

  #
  al khaliji France mortgage

  Flat
  Rate

  ### 2.33%

  Reducing
  Rate

  ### 3.99%

  Minimum
  Salary

  ### AED 25,000

  Islamic
  Finance

  ### No

  Salary
  Transfer

  ### No

  Introductory
  Offers

  ### No

  More Info

Home Price ( AED )
Deposit Amount ( AED )
Terms (years)
*Calculations are based on flat rates

# What features would you like to have with your Home Loan? #### Filter By Islamic Finance No Salary Transfer Transfer Mortgage Islamic Finance No Salary Transfer Transfer Mortgage
# Looking for a specific bank? View All

Provider | Minimum Salary | Down Payment | Monthly Payment |  | Rate | Flat Rate | Reducing Rate |  | Features |  |  |
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
al khaliji France mortgage

Minimum Salary:
AED 25,000 Down Payment: 20%
AED 20,000,000 Salary Transfer: No Islamic Finance: No 2.33% Flat Rate: 2.33% | Reducing Rate: 3.99% Flat Rate: 2.33% Reducing Rate: 3.99%
More Info Compare
More Info
Apply Now
1 1 al khaliji
NBQ Bayti Al Tayseer – Islamic
Minimum Salary:
AED 30,000 Down Payment: 0%
AED 5,000,000 Salary Transfer: Yes Islamic Finance: Yes 0.00% Flat Rate: 0.00% | Reducing Rate: 0.00% Flat Rate: - Reducing Rate: -
More Info Compare
More Info
Apply Now
Islamic Finance,Salary Transfer, 0 1 National Bank of Umm Al Qaiwain
DIB Ijarah for Expats
Minimum Salary:
AED 12,000 Down Payment: 20%
AED 7,000,000 Salary Transfer: No Islamic Finance: Yes 1.94% Flat Rate: 1.94% | Reducing Rate: 3.49% Flat Rate: - Reducing Rate: 3.49%
More Info Compare
More Info
Apply Now
Islamic Finance, 0 1 Dubai Islamic Bank
ADF residential mortgages
Minimum Salary:
AED 10,000 Down Payment: 20%
AED 0 Salary Transfer: No Islamic Finance: No 1.68% Flat Rate: 1.68% | Reducing Rate: 3.02% Flat Rate: 1.68% Reducing Rate: 3.02%
More Info Compare
More Info
Apply Now
0 1 Abu Dhabi Finance
UAB Home Finance
Minimum Salary:
AED 15,000 Down Payment: 20%
AED 10,000,000 Salary Transfer: No Islamic Finance: Yes 2.22% Flat Rate: 2.22% | Reducing Rate: 3.99% Flat Rate: 2.22% Reducing Rate: 3.99%
More Info Compare
More Info
Apply Now
Islamic Finance, 0 1 United Arab Bank
Emirates Islamic Manzili Home Finance
Minimum Salary:
AED 15,000 Down Payment: 25%
AED 5,000,000 Salary Transfer: No Islamic Finance: Yes 1.63% Flat Rate: 1.63% | Reducing Rate: 2.95% Flat Rate: 1.63% Reducing Rate: 2.95%
More Info Compare
More Info
Apply Now
Islamic Finance, 0 1 Emirates Islamic
ADIB Home Finance for UAE Nationals
Minimum Salary:
AED 10,000 Down Payment: 20%
AED 20,000,000 Salary Transfer: No Islamic Finance: Yes 1.65% Flat Rate: 1.65% | Reducing Rate: 2.99% Flat Rate: 1.65% Reducing Rate: 2.99%
More Info Compare
More Info
Apply Now
Islamic Finance, 0 1 Abu Dhabi Islamic Bank
RAK Bank Home Loan
Minimum Salary:
AED 15,000 Down Payment: 25%
AED 13,000,000 Salary Transfer: No Islamic Finance: No 1.65% Flat Rate: 1.65% | Reducing Rate: 2.99% Flat Rate: 1.65% Reducing Rate: 2.99%
More Info Compare
More Info
Apply Now
0 1 RAKBANK
CBD Mortgage Loan
Minimum Salary:
AED 15,000 Down Payment: 25%
AED 9,000,000 Salary Transfer: No Islamic Finance: Yes 2.22% Flat Rate: 2.22% | Reducing Rate: 3.99% Flat Rate: 2.22% Reducing Rate: 3.99%
More Info Compare
More Info
Apply Now
Islamic Finance, 0 1 Commercial Bank of Dubai
CBI Home Loan
Minimum Salary:
AED 15,000 Down Payment: 25%
AED 500,000 Salary Transfer: No Islamic Finance: No 3.75% Flat Rate: 3.75% | Reducing Rate: 6.75% Flat Rate: 3.75% Reducing Rate: 6.75%
More Info Compare
More Info
Apply Now
0 1 Commercial Bank International

- 1
- 2
- 3
- 4
- »

Want to stay up to date with our latest products and offers?
Sign up for our newsletter today!

# Got a question?

### How do I choose a home loan provider?

Compare, compare, compare! Use our smart comparison tools to choose the best home loan for you. You may also wish to consider using a mortgage advisor such as Best Rate, who will do the hard work for you, recommend the best product for your needs and help you through the entire process from consultation to completion.

### What key criteria should I consider before taking out a home loan?

- Fixed Rate v Variable Rate – a fixed rate provides more stability and is best if you expect interest rates to go up whereas with a variable rate, you can benefit when the interest rate goes down
- Loan amount – this will depend on a number of criteria including your financial situation, deposit amount and the price of the property you wish to purchase
- Down payment – consider what the required down payment / deposit will be in order to help you set a budget
- Interest rates – do flat or reducing interest rates apply? See below for details of how these differ
- Tenure – this is the length of time you have to pay back your loan and will vary depending on the bank and / or loan product
- Minimum salary requirement – UAE banks normally impose a minimum salary required to take out a home loan so select a provider from those whose minimum salary requirement is less or the same as your salary
- Fees – consider all fees applicable such as arrangement fees and early settlement fees
- Other benefits – does the bank provide options for a payment holiday

### What is the difference between a Fixed Rate and a Variable Rate home loan?

With a fixed rate home loan, you repay a fixed rate for a set number of years. With a variable rate, the repayment amount varies with the market rate, which means your repayments can change as the rate changes.

### Will a bank lend me the full amount required to purchase my property?

No. You will need to pay a down payment / deposit and the bank will also carry out a valuation of the property and base the amount they lend you on this value rather than the purchase price. Any difference between what the bank lends you and what you need to pay to buy the property needs to be paid by you. A bank will commonly lend you 70%-85% of the property value.

### Do I need to have a down payment / deposit?

Yes. In the UAE, it is a requirement to pay a down payment or deposit. The amount required will depend on whether you are a UAE national, resident expat or non-resident as well as your employment status and whether you are a first time buyer.

### Should I apply for a home loan before looking for a property?

We advise you to obtain a pre-approval, which will help you to determine your budget. A pre-approval normally has a validity of one to three months, which is the time you have to make an offer on your chosen property. Once done, you can proceed with obtaining the final offer and completing the transfer process.

### Can I take out a home loan as a first time buyer, non-resident or if I am self-employed?

Yes. Depending on your individual situation, different documents are required. Your chosen provider will provide you with details.

### What is an arrangement fee?

This relates to what the bank will charge you at the beginning of the loan and is normally added to your principal loan amount. Some banks may offer home loan products with no arrangement fee but others may charge a fixed fee or a percentage of your total loan amount.

### What is an early settlement fee?

This relates to the fee applicable if you decide to pay off your loan early. If, for example, you take a home loan for 25 years but expect to be in a position to pay if off before then, any early settlement fee becomes an important factor in choosing your home loan provider.

### What is the difference between Flat and Reducing Interest Rates?

Rates on home loans can be calculated in two ways – as a reducing rate or as a flat rate. With a flat rate, the rate is calculated on the entire principal amount of a loan (the full, original amount borrowed) whereas with a reducing interest rate, interest is charged only on the outstanding amount of the loan on a periodic basis.

Flat interest rates are normally lower than the reducing balance rate and therefore considered misleading. When it comes to comparing loans, the best way to compare their true cost is to convert everything into the Reducing Interest Rate equivalent (click here for more information)

### How long do I have to settle my home loan?

Tenures range on mortgages so make sure you take into account the tenure period when choosing a home loan product. Be sure to consider early settlement fees as well, in the event that you are in a position to make early repayments and settle your debt early.

### What if I wish to sell the property before paying off the loan?

You are free to sell your property as and when you choose. You’ll just need to repay the full outstanding balance of your home loan at the time of sale.

### What documents do I need in order to apply for a home loan?

Your residency and employment status will determine the exact documents you will require to submit on application. Your chosen loan provider will provide you with all details.

### Do I need to transfer my salary to my home loan provider?

Not necessarily but doing so will often get you a better rate as you are then considered less risky to the institution.

### Do I need to take out insurance on my home loan?

Yes, both life insurance and property insurance for those taking a home loan is mandatory. The policies must cover the tenure of the loan, the loan value and be active with payments fully up to date.

# Compare Home Loans ...

# Filter by Features

Calculate your mortgage today! Powered by ADIB Calculate Now
Redirect

# Welcome to compareit4me.com

Looks like your visiting our site from Kuwait.
We have a dedicated site for Kuwait.
Would you like to visit that instead?
Yes, take me to the Kuwait site
Redirect

# Welcome to compareit4me.com

Looks like your visiting our site from Qatar.
We have a dedicated site for Qatar.
Would you like to visit that instead?
Yes, take me to the Qatar site
Redirect

# Welcome to compareit4me.com

Looks like your visiting our site from Bahrain.
We have a dedicated site for Bahrain.
Would you like to visit that instead?
Yes, take me to the Bahrain site

##### Compare Home Loans

Compare